* `delegate` - send a task to another agent from the list provided. Arguments:
  * `agent` - the agent to which the task is delegated. MUST match a name in the list of agents provided.
  * `inputs` - a dictionary of input parameters to the agent, as specified in the list
